#ifndef SCREENMANAGER_H
#define SCREENMANAGER_H
#include "definition.h"
#include <Adafruit_SSD1306.h>

class ScreenManager
{
  friend class SAB;
  public:
    boolean addView(boolean (*viewLogicFunction)(Adafruit_SSD1306&, void*), void *pData, const unsigned char UID);
    boolean removeView(const unsigned char UID);
    boolean displayView(const int UID = -1);
    void invertDisplayColor(const boolean inverted);
    void orientDisplay(const Orientation orientation);
    void dimDisplay(const boolean dimmed);
    void clearDisplay(const boolean bufferOnly = false);
    
    unsigned char getError() const;
    boolean isDisplayColorInverted() const;
    Orientation getDisplayOrientation() const;
    boolean isDisplayDimmed() const;
    ViewLink* getCurrentView() const;

    
    void iterateThroughList();
    
  protected:
    ScreenManager(Adafruit_SSD1306 &display);
  private:
    void *createEmptyList();
    boolean addNewLinkAtTheEnd(ViewLinkedList *viewLinkedList, ViewLink viewLink);
    boolean removeLinkByUID(ViewLinkedList *viewLinkedList, const unsigned char UID);
    ViewLink* getLinkByUID(ViewLinkedList viewLinkedList, const unsigned char UID);
    boolean isListEmpty(ViewLinkedList viewLinkedList);
    
    Adafruit_SSD1306 &_displayRef;
    ViewLinkedList _viewLinkedList;
    unsigned char _error;
    boolean _displayColorInverted;
    boolean _displayDimmed;
    ViewLink* _currentView;
};

#endif //SCREENMANAGER_H
